/*
  "Our Solar System" by Yana Kuznetsova, Pau Padrós and Eirene Zhen Pérez.

  This program works in conjunction with the Processing code found on Instructables.
  Build the physical model and load this program into the Arduino Uno.

  Load into Arduino the "HC-SR04" Library by Dirk Sarodnick.
  You do that by going... Sketch - Include Library - Manage Libraries and then search for "HC-SR04" by Dirk Sarodnick and install it.
*/

//We include the library we have just installed and assign pins 6 and 7 to the output and input of the ultrasonic sensor.
#include <HCSR04.h>


byte triggerPin = 7;
byte echoPin = 6;

int led = 9;
int brightness = 0;


void setup() {
  //We initalise the ultrasonic sensor. We initialize serial communications at a 9600 baud rate.
  Serial.begin(9600);
  HCSR04.begin(triggerPin, echoPin);

  //We initialize analogue pin "led" (you can change the pin number above if needed) as an output
  pinMode(led, OUTPUT);
}

void loop() {
  //We establish the conditions under which some LEDs with turn off to leave the "kill him" message on. By default, the message will appear when the sensor reads 120cm (47 inches) or less. You can change that value to one that suits you by changing the value of int distanceActive on top of the code.
  double* distances = HCSR04.measureDistanceCm();

  //We map the values that distances to 0cm, 200cm, 255 (fully on), 0 (fully off).
  brightness = map(distances[0], 0, 200, 255, 0);

  //We tell the LED to turn of as long as the brightness is higher than 0.
  if (brightness > 0) {
    analogWrite(led, brightness);
  }

  //The rest of the program is a set of if structures that the program will enter in the case that the distance were to be between the two thresholds. When inside the if, it writes a String on the Serial port and waits for half a a second.
  if ((distances[0]) < 40 && (distances[0] > 0)) {
    //send 'Sun' over the serial port
    Serial.write("Sun\n");
    //wait 100 milliseconds so we don't drive ourselves crazy
    delay(500);

  } else if ((distances[0] < 50) && (distances[0] > 40)) {
    //send 'Rocky Planets' over the serial port
    Serial.write("Rocky\n");
    //wait 100 milliseconds so we don't drive ourselves crazy
    delay(500);

  } else if ((distances[0] < 75) && (distances[0] > 50)) {
    //send 'Jupiter' to the serial port
    Serial.write("Jupiter\n");
    //wait 100 milliseconds so we don't drive ourselves crazy
    delay(500);

  } else if ((distances[0] < 103) && (distances[0] > 75)) {
    //send 'Saturn' to the serial port
    Serial.write("Saturn\n");
    //wait 100 milliseconds so we don't drive ourselves crazy
    delay(500);

  } else if ((distances[0] < 167) && (distances[0] > 103)) {
    //send 'Uranus' to the serial port
    Serial.write("Uranus\n");
    //wait 100 milliseconds so we don't drive ourselves crazy
    delay(500);

  } else if ((distances[0] < 200) && (distances[0] > 167)) {
    //send 'Neptune' to the serial port
    Serial.write("Neptune\n");
    //wait 100 milliseconds so we don't drive ourselves crazy
    delay(500);

  } else if (distances[0] > 200) {
    //send 'Space' to the serial port
    Serial.write("Space\n");
    //wait 100 milliseconds so we don't drive ourselves crazy
    delay(500);
  }
}
